==> bookshelf-fabric-1.21.1-21.1.62-sources.jar: net/darkhax/bookshelf/common/impl/BookshelfContent.java <==
package net.darkhax.bookshelf.common.impl;

import com.mojang.brigadier.CommandDispatcher;
import com.mojang.brigadier.builder.LiteralArgumentBuilder;
import com.mojang.serialization.MapCodec;
import net.darkhax.bookshelf.common.api.commands.args.FontArgument;
import net.darkhax.bookshelf.common.api.commands.args.TagArgument;
import net.darkhax.bookshelf.common.api.data.conditions.ILoadCondition;
import net.darkhax.bookshelf.common.api.loot.LootPoolEntryDescriptions;
import net.darkhax.bookshelf.common.api.registry.IContentProvider;
import net.darkhax.bookshelf.common.api.registry.register.ArgumentRegister;
import net.darkhax.bookshelf.common.api.registry.register.Register;
import net.darkhax.bookshelf.common.api.registry.register.RegisterIngredient;
import net.darkhax.bookshelf.common.api.registry.register.RegisterLootDescription;
import net.darkhax.bookshelf.common.api.service.Services;
import net.darkhax.bookshelf.common.impl.command.BlockTagToItemTagCommand;
import net.darkhax.bookshelf.common.impl.command.DebugCommands;
import net.darkhax.bookshelf.common.impl.command.EnchantCommand;
import net.darkhax.bookshelf.common.impl.command.FontCommand;
import net.darkhax.bookshelf.common.impl.command.HandCommand;
import net.darkhax.bookshelf.common.impl.command.RenameCommand;
import net.darkhax.bookshelf.common.impl.command.TranslateCommand;
import net.darkhax.bookshelf.common.impl.data.conditions.And;
import net.darkhax.bookshelf.common.impl.data.conditions.ModLoaded;
import net.darkhax.bookshelf.common.impl.data.conditions.Not;
import net.darkhax.bookshelf.common.impl.data.conditions.OnPlatform;
import net.darkhax.bookshelf.common.impl.data.conditions.Or;
import net.darkhax.bookshelf.common.impl.data.conditions.RegistryContains;
import net.darkhax.bookshelf.common.impl.data.criterion.item.NamespaceItemPredicate;
import net.darkhax.bookshelf.common.impl.data.criterion.trigger.AdvancementTrigger;
import net.darkhax.bookshelf.common.impl.data.ingredient.AllOfIngredient;
import net.darkhax.bookshelf.common.impl.data.ingredient.BlockTagIngredient;
import net.darkhax.bookshelf.common.impl.data.ingredient.EitherIngredient;
import net.darkhax.bookshelf.common.impl.data.ingredient.FalseIngredient;
import net.darkhax.bookshelf.common.impl.data.ingredient.ModIdIngredient;
import net.darkhax.bookshelf.common.impl.data.loot.entries.LootItemStack;
import net.minecraft.class_179;
import net.minecraft.class_2168;
import net.minecraft.class_2170;
import net.minecraft.class_7157;
import net.minecraft.class_75;
import net.minecraft.class_79;
import net.minecraft.class_7923;
import net.minecraft.class_9360;

public class BookshelfContent implements IContentProvider {

    @Override
    public String contentNamespace() {
        return Constants.MOD_ID;
    }

    @Override
    public void registerCommands(CommandDispatcher<class_2168> dispatcher, class_7157 context, class_2170.class_5364 selection) {
        final LiteralArgumentBuilder<class_2168> root = LiteralArgumentBuilder.literal(Constants.MOD_ID);
        root.then(HandCommand.build(context));
        root.then(FontCommand.build());
        root.then(RenameCommand.build(context));
        root.then(EnchantCommand.build(context));
        root.then(TranslateCommand.build(context));
        root.then(BlockTagToItemTagCommand.build(context));
        if (Services.PLATFORM.isDevelopmentEnvironment() && Services.PLATFORM.isPhysicalClient() && selection == class_2170.class_5364.field_25421) {
            root.then(DebugCommands.build(context));
        }
        dispatcher.register(root);
    }

    @Override
    public void registerCommandArguments(ArgumentRegister register) {
        register.accept("font", FontArgument.class, FontArgument.SERIALIZER);
        register.accept("tag", TagArgument.class, TagArgument.SERIALIZER);
    }

    @Override
    public void registerIngredientTypes(RegisterIngredient registry) {
        registry.add("false", FalseIngredient.CODEC, FalseIngredient.STREAM);
        registry.add("all", AllOfIngredient.CODEC, AllOfIngredient.STREAM);
        registry.add("either", EitherIngredient.CODEC, EitherIngredient.STREAM);
        registry.add("mod_id", ModIdIngredient.CODEC, ModIdIngredient.STREAM);
        registry.add("block_tag", BlockTagIngredient.CODEC, BlockTagIngredient.STREAM);
    }

    @Override
    public void registerLoadConditions(Register<MapCodec<? extends ILoadCondition>> registry) {
        registry.add(And.TYPE_ID, And.CODEC);
        registry.add(Not.TYPE_ID, Not.CODEC);
        registry.add(Or.TYPE_ID, Or.CODEC);
        registry.add(OnPlatform.TYPE_ID, OnPlatform.CODEC);
        registry.add(ModLoaded.TYPE_ID, ModLoaded.CODEC);
        registry.add(RegistryContains.BLOCK, RegistryContains.of(RegistryContains.BLOCK, class_7923.field_41175));
        registry.add(RegistryContains.ITEM, RegistryContains.of(RegistryContains.ITEM, class_7923.field_41178));
        registry.add(RegistryContains.ENTITY, RegistryContains.of(RegistryContains.ENTITY, class_7923.field_41177));
        registry.add(RegistryContains.BLOCK_ENTITY, RegistryContains.of(RegistryContains.BLOCK_ENTITY, class_7923.field_41181));
    }

    @Override
    public void registerItemSubPredicates(Register<class_9360.class_8745<?>> registry) {
        registry.add("namespace", new class_9360.class_8745<>(NamespaceItemPredicate.CODEC));
    }

    @Override
    public void registerCriteriaTriggers(Register<class_179<?>> registry) {
        registry.add("earn_advancement", AdvancementTrigger.TRIGGER);
    }

    @Override
    public void registerLootEntryType(Register<MapCodec<? extends class_79>> register) {
        register.add("item_stack", LootItemStack.CODEC);
    }

    @Override
    public void registerLootDescriptions(RegisterLootDescription registry) {
        registry.registryFunc().accept(class_75.field_25206, LootPoolEntryDescriptions.EMPTY);
        registry.registryFunc().accept(class_75.field_25207, LootPoolEntryDescriptions.ITEM);
        registry.registryFunc().accept(class_75.field_25208, LootPoolEntryDescriptions.LOOT_TABLE);
        registry.registryFunc().accept(class_75.field_25209, LootPoolEntryDescriptions.DYNAMIC);
        registry.registryFunc().accept(class_75.field_25210, LootPoolEntryDescriptions.TAG);
        registry.registryFunc().accept(class_75.field_25211, LootPoolEntryDescriptions.COMPOSITE);
        registry.registryFunc().accept(class_75.field_25212, LootPoolEntryDescriptions.COMPOSITE);
        registry.registryFunc().accept(class_75.field_25213, LootPoolEntryDescriptions.COMPOSITE);
        registry.registryFunc().accept(class_7923.field_41133.method_10223(Constants.id("item_stack")), LootPoolEntryDescriptions.ITEM_STACK);
    }
}

==> bookshelf-fabric-1.21.1-21.1.65-sources.jar: net/darkhax/bookshelf/common/impl/BookshelfContent.java <==
package net.darkhax.bookshelf.common.impl;

import com.mojang.brigadier.CommandDispatcher;
import com.mojang.brigadier.builder.LiteralArgumentBuilder;
import com.mojang.serialization.MapCodec;
import net.darkhax.bookshelf.common.api.commands.PermissionLevel;
import net.darkhax.bookshelf.common.api.commands.args.FontArgument;
import net.darkhax.bookshelf.common.api.commands.args.TagArgument;
import net.darkhax.bookshelf.common.api.data.conditions.ILoadCondition;
import net.darkhax.bookshelf.common.api.loot.LootPoolEntryDescriptions;
import net.darkhax.bookshelf.common.api.registry.IContentProvider;
import net.darkhax.bookshelf.common.api.registry.register.ArgumentRegister;
import net.darkhax.bookshelf.common.api.registry.register.Register;
import net.darkhax.bookshelf.common.api.registry.register.RegisterIngredient;
import net.darkhax.bookshelf.common.api.registry.register.RegisterLootDescription;
import net.darkhax.bookshelf.common.api.service.Services;
import net.darkhax.bookshelf.common.impl.command.BlockTagToItemTagCommand;
import net.darkhax.bookshelf.common.impl.command.DebugCommands;
import net.darkhax.bookshelf.common.impl.command.EnchantCommand;
import net.darkhax.bookshelf.common.impl.command.FontCommand;
import net.darkhax.bookshelf.common.impl.command.HandCommand;
import net.darkhax.bookshelf.common.impl.command.RenameCommand;
import net.darkhax.bookshelf.common.impl.command.StructureCommand;
import net.darkhax.bookshelf.common.impl.command.TranslateCommand;
import net.darkhax.bookshelf.common.impl.data.conditions.And;
import net.darkhax.bookshelf.common.impl.data.conditions.ModLoaded;
import net.darkhax.bookshelf.common.impl.data.conditions.Not;
import net.darkhax.bookshelf.common.impl.data.conditions.OnPlatform;
import net.darkhax.bookshelf.common.impl.data.conditions.Or;
import net.darkhax.bookshelf.common.impl.data.conditions.RegistryContains;
import net.darkhax.bookshelf.common.impl.data.criterion.item.NamespaceItemPredicate;
import net.darkhax.bookshelf.common.impl.data.criterion.trigger.AdvancementTrigger;
import net.darkhax.bookshelf.common.impl.data.ingredient.AllOfIngredient;
import net.darkhax.bookshelf.common.impl.data.ingredient.BlockTagIngredient;
import net.darkhax.bookshelf.common.impl.data.ingredient.EitherIngredient;
import net.darkhax.bookshelf.common.impl.data.ingredient.FalseIngredient;
import net.darkhax.bookshelf.common.impl.data.ingredient.ModIdIngredient;
import net.darkhax.bookshelf.common.impl.data.loot.entries.LootItemStack;
import net.minecraft.class_179;
import net.minecraft.class_2168;
import net.minecraft.class_2170;
import net.minecraft.class_7157;
import net.minecraft.class_75;
import net.minecraft.class_79;
import net.minecraft.class_7923;
import net.minecraft.class_9360;

public class BookshelfContent implements IContentProvider {

    @Override
    public String contentNamespace() {
        return Constants.MOD_ID;
    }

    @Override
    public void registerCommands(CommandDispatcher<class_2168> dispatcher, class_7157 context, class_2170.class_5364 selection) {
        final LiteralArgumentBuilder<class_2168> root = class_2170.method_9247(Constants.MOD_ID).requires(PermissionLevel.MODERATOR);
        root.then(HandCommand.build(context));
        root.then(FontCommand.build());
        root.then(RenameCommand.build(context));
        root.then(EnchantCommand.build(context));
        root.then(TranslateCommand.build(context));
        root.then(BlockTagToItemTagCommand.build(context));
        root.then(StructureCommand.build());
        if (Services.PLATFORM.isDevelopmentEnvironment() && Services.PLATFORM.isPhysicalClient() && selection == class_2170.class_5364.field_25421) {
            root.then(DebugCommands.build(context));
        }
        dispatcher.register(root);
    }

    @Override
    public void registerCommandArguments(ArgumentRegister register) {
        register.accept("font", FontArgument.class, FontArgument.SERIALIZER);
        register.accept("tag", TagArgument.class, TagArgument.SERIALIZER);
    }

    @Override
    public void registerIngredientTypes(RegisterIngredient registry) {
        registry.add("false", FalseIngredient.CODEC, FalseIngredient.STREAM);
        registry.add("all", AllOfIngredient.CODEC, AllOfIngredient.STREAM);
        registry.add("either", EitherIngredient.CODEC, EitherIngredient.STREAM);
        registry.add("mod_id", ModIdIngredient.CODEC, ModIdIngredient.STREAM);
        registry.add("block_tag", BlockTagIngredient.CODEC, BlockTagIngredient.STREAM);
    }

    @Override
    public void registerLoadConditions(Register<MapCodec<? extends ILoadCondition>> registry) {
        registry.add(And.TYPE_ID, And.CODEC);
        registry.add(Not.TYPE_ID, Not.CODEC);
        registry.add(Or.TYPE_ID, Or.CODEC);
        registry.add(OnPlatform.TYPE_ID, OnPlatform.CODEC);
        registry.add(ModLoaded.TYPE_ID, ModLoaded.CODEC);
        registry.add(RegistryContains.BLOCK, RegistryContains.of(RegistryContains.BLOCK, class_7923.field_41175));
        registry.add(RegistryContains.ITEM, RegistryContains.of(RegistryContains.ITEM, class_7923.field_41178));
        registry.add(RegistryContains.ENTITY, RegistryContains.of(RegistryContains.ENTITY, class_7923.field_41177));
        registry.add(RegistryContains.BLOCK_ENTITY, RegistryContains.of(RegistryContains.BLOCK_ENTITY, class_7923.field_41181));
    }

    @Override
    public void registerItemSubPredicates(Register<class_9360.class_8745<?>> registry) {
        registry.add("namespace", new class_9360.class_8745<>(NamespaceItemPredicate.CODEC));
    }

    @Override
    public void registerCriteriaTriggers(Register<class_179<?>> registry) {
        registry.add("earn_advancement", AdvancementTrigger.TRIGGER);
    }

    @Override
    public void registerLootEntryType(Register<MapCodec<? extends class_79>> register) {
        register.add("item_stack", LootItemStack.CODEC);
    }

    @Override
    public void registerLootDescriptions(RegisterLootDescription registry) {
        registry.registryFunc().accept(class_75.field_25206, LootPoolEntryDescriptions.EMPTY);
        registry.registryFunc().accept(class_75.field_25207, LootPoolEntryDescriptions.ITEM);
        registry.registryFunc().accept(class_75.field_25208, LootPoolEntryDescriptions.LOOT_TABLE);
        registry.registryFunc().accept(class_75.field_25209, LootPoolEntryDescriptions.DYNAMIC);
        registry.registryFunc().accept(class_75.field_25210, LootPoolEntryDescriptions.TAG);
        registry.registryFunc().accept(class_75.field_25211, LootPoolEntryDescriptions.COMPOSITE);
        registry.registryFunc().accept(class_75.field_25212, LootPoolEntryDescriptions.COMPOSITE);
        registry.registryFunc().accept(class_75.field_25213, LootPoolEntryDescriptions.COMPOSITE);
        registry.registryFunc().accept(class_7923.field_41133.method_10223(Constants.id("item_stack")), LootPoolEntryDescriptions.ITEM_STACK);
    }
}
